==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeProVersionStatusRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeProVersionStatusRequest extends AbstractModel{

    /**
    * 云镜客户端UUID、填写"all"表示所有主机。
    */
    @SerializedName("Uuid")
    @Expose
    private String Uuid;

    /**
     * Get 云镜客户端UUID、填写"all"表示所有主机。 
     * @return Uuid 云镜客户端UUID、填写"all"表示所有主机。
     */
    public String getUuid() {
        return this.Uuid;
    }

    /**
     * Set 云镜客户端UUID、填写"all"表示所有主机。
     * @param Uuid 云镜客户端UUID、填写"all"表示所有主机。
     */
    public void setUuid(String Uuid) {
        this.Uuid = Uuid;
    }

    public DescribeProVersionStatusRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeProVersionStatusRequest(DescribeProVersionStatusRequest source) {
        if (source.Uuid != null) {
            this.Uuid = new String(source.Uuid);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Uuid", this.Uuid);

    }
}

==> tencentcloud-sdk-java-3.1.757-sources.jar: com/tencentcloudapi/cwp/v20180228/models/DescribeProVersionStatusRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeProVersionStatusRequest extends AbstractModel{

    /**
    * 主机安全客户端UUID、填写"all"表示所有主机。
    */
    @SerializedName("Uuid")
    @Expose
    private String Uuid;

    /**
     * Get 主机安全客户端UUID、填写"all"表示所有主机。 
     * @return Uuid 主机安全客户端UUID、填写"all"表示所有主机。
     */
    public String getUuid() {
        return this.Uuid;
    }

    /**
     * Set 主机安全客户端UUID、填写"all"表示所有主机。
     * @param Uuid 主机安全客户端UUID、填写"all"表示所有主机。
     */
    public void setUuid(String Uuid) {
        this.Uuid = Uuid;
    }

    public DescribeProVersionStatusRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeProVersionStatusRequest(DescribeProVersionStatusRequest source) {
        if (source.Uuid != null) {
            this.Uuid = new String(source.Uuid);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Uuid", this.Uuid);

    }
}
